import { mergeProps, getNextElement, spread, insert, isServer, ssr, effect, innerHTML, runHydrationEvents, template } from 'solid-js/web';
import { splitProps, createSignal, createEffect, onCleanup } from 'solid-js';

const _tmpl$ = /*#__PURE__*/template(`<svg stroke-width="0"></svg>`, 2),
  _tmpl$2 = /*#__PURE__*/template(`<svg><g></g></svg>`, 4, true);
const CustomIcon = props => IconTemplate(props.src, props);
function IconTemplate(iconSrc, props) {
  const mergedProps = mergeProps(iconSrc.a, props);
  const [_, svgProps] = splitProps(mergedProps, ["src"]);
  const [content, setContent] = createSignal("");

  // When the component is mounted on the client, set the SVG content.
  createEffect(() => setContent(iconSrc.c));

  // Cleanup the signal on component unmount.
  onCleanup(() => {
    setContent("");
  });
  return (() => {
    const _el$ = getNextElement(_tmpl$);
    spread(_el$, mergeProps({
      get stroke() {
        return iconSrc.a?.stroke;
      },
      get color() {
        return props.color || "currentColor";
      },
      get fill() {
        return props.color || "currentColor";
      },
      get style() {
        return {
          ...props.style,
          overflow: "visible"
        };
      }
    }, svgProps, {
      get height() {
        return props.size || "1em";
      },
      get width() {
        return props.size || "1em";
      },
      "xmlns": "http://www.w3.org/2000/svg",
      get innerHTML() {
        return content();
      }
    }), true, true);
    insert(_el$, () => isServer && ssr((() => {
      const _el$2 = getNextElement(_tmpl$2);
      effect(() => innerHTML(_el$2, iconSrc.c));
      return _el$2;
    })()));
    runHydrationEvents();
    return _el$;
  })();
}

export { CustomIcon, IconTemplate };
